==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/server/inc/cache/account.php <==
<?php

/**
 * @class CacheAccount
 * @brief Class representing a cached account.
 * @author Martin Zlomek
 * @date 02-03-2006
 */
class CacheAccount extends Account {
	/** Parent user object. */
	public $user;

	/** ID of the account. */
	public $accountID;

	/**
	 * @brief Create a new account object.
	 * @param $user Parent user object of the account.
	 * @param $accountID ID of the account.
	 * @param $server Name of the server where the account is located.
	 * @param $port Port where connect to on the server.
	 * @param $username Account logging username.
	 * @param $password Account logging password.
	 */
	protected function __construct($user, $accountID,
									$server, $port, $username, $password,$primary,$protocol = 'IMAP',$properties = false)
	{
		require_once('inc/account.php');
    require_once('inc/cache/cache.php');
    require_once('inc/localpop/folder.php');
    
    parent::__construct($server, $port, $username, $password,$properties);

		$this->user	  = $user;
		$this->accountID = $accountID;
		$this->primary = $primary;
		$this->protocol = strtoupper($protocol);

    $this->loadFolders($this->folderClassName);

    
  }

	/**
	 * @brief Load the list of account folders.
	 * @param $class Class of the folder objects.
	 */
	protected function loadFolders($class = 'IMAPFolder')
	{
		$cache = new Cache($this->user,$this->protocol);
		$this->folders['main'] = $cache->getFolders($this, $class);
	 
    if ($class=='LocalPOPFolder')
		  foreach($this->folders['main'] as $fdrID => $folder){
        if ($fdrID!=$folder->name){
          unset($this->folders['main'][$fdrID]);
          $this->folders['main'][$folder->folderID] = $folder;
        }
      }
	}

	/**
	 * @brief Create a new folder.
	 * @param $name Name of the folder.
	 */
	protected function createFolder($name)
	{
		parent::createFolder($name);
	}

	/**
	 * @brief Synchronize the folder cache with the list of folders.
	 * @param $folders The list of folders.
	 */
	protected function sync($folders)
	{

		$cache = new Cache($this->user,$this->protocol);
		$cache->transaction();

		/* Get cached folders. */
		$foldersID = $cache->getFoldersID($this->accountID);

		/* Cache new folders. */
		ksort($folders);

		foreach ($folders as $folder) {

			if (isset($foldersID[$folder->name])) {
				$folderID = &$foldersID[$folder->name];
				if ($folder->rights != $folderID['rights']) {
					$cache->updateFolder($folderID['folder_id'],
										 array('rights' => $folder->rights));
				}

				$folderID = $folderID['folder_id'];
			} else {
				$parentFolderName = preg_replace('/\/[^\/]*$/', '',
												 $folder->name);

				if (isset($foldersID[$parentFolderName])
					&& !is_array($foldersID[$parentFolderName]))
				{
					$parentFolderID = $foldersID[$parentFolderName];
				} else
					$parentFolderID = null;
        
				$folderID = $cache->createFolder(array('parent_folder_id' => $parentFolderID,
														'account_id'		=> $this->accountID,
														'name'			 =>  $folder->name,
														'rights'			=> $folder->rights));
				$foldersID[$folder->name] = $folderID;
			}
		}

		/* Delete folders from the folder cache. */
		foreach ($foldersID as $folderID) {
			if (is_array($folderID))
				$cache->deleteFolder($this->accountID, $folderID['folder_id']);
		}

		$cache->commit();

		/* Update the internal list of folders. */
		$oAccount = $this->user->getAccount($this->accountID);

	  $this->loadFolders($this->folderClassName);
	}
	
	public function search($sPhrase){

	  /* Filter to use for search in items */
    $sFilter = "(SUBJECT LIKE '%".$sPhrase."%' OR HEADER_TO LIKE '%".$sPhrase."%' OR HEADER_FROM LIKE '%".$sPhrase."%')";

    //Create filter formatted to use in webmail folder classes
    $aFilterTag['tag'] = false;
    $aFilterTag['sql'] = $sFilter;
    
    foreach($this->folders["main"] as $sFolderID => $oFolder){
      $oItems = $oFolder->getItems($aFilterTag);
      foreach($oItems as $oItem)
        $aFoundItems[] = $oItem->itemID; 
    }
    return $aFoundItems;     
  }
  
  public function cleanUpCache(){
    $cache = new Cache($this->user);

    foreach($this->folders["main"] as $sFolderID => $oFolder)
      $cache->deleteFolder($this->accountID,$oFolder->folderID);
  }
}

require_once('inc/imap/account.php');

?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/server/inc/cache/account.php <==
<?php

/**
 * @class CacheAccount
 * @brief Class representing a cached account.
 * @author Martin Zlomek
 * @date 02-03-2006
 */
class CacheAccount extends Account {
	/** Parent user object. */
	public $user;

	/** ID of the account. */
	public $accountID;

	/**
	 * @brief Create a new account object.
	 * @param $user Parent user object of the account.
	 * @param $accountID ID of the account.
	 * @param $server Name of the server where the account is located.
	 * @param $port Port where connect to on the server.
	 * @param $username Account logging username.
	 * @param $password Account logging password.
	 */
	protected function __construct($user, $accountID,
									$server, $port, $username, $password,$primary,$protocol = 'IMAP',$properties = false)
	{
		require_once('inc/account.php');
    require_once('inc/cache/cache.php');
    require_once('inc/localpop/folder.php');
    
    parent::__construct($server, $port, $username, $password,$properties);

		$this->user	  = $user;
		$this->accountID = $accountID;
		$this->primary = $primary;
		$this->protocol = strtoupper($protocol);

    $this->loadFolders($this->folderClassName);

    
  }

	/**
	 * @brief Load the list of account folders.
	 * @param $class Class of the folder objects.
	 */
	protected function loadFolders($class = 'IMAPFolder')
	{
		$cache = Cache::instance($this->user);
		$this->folders['main'] = $cache->getFolders($this, $class);
	 
    if ($class=='LocalPOPFolder')
		  foreach($this->folders['main'] as $fdrID => $folder){
        if ($fdrID!=$folder->name){
          unset($this->folders['main'][$fdrID]);
          $this->folders['main'][$folder->folderID] = $folder;
        }
      }
	}

	/**
	 * @brief Create a new folder.
	 * @param $name Name of the folder.
	 */
	protected function createFolder($name)
	{
		parent::createFolder($name);
	}

	/**
	 * @brief Synchronize the folder cache with the list of folders.
	 * @param $folders The list of folders.
	 */
	protected function sync($folders)
	{

		$cache = Cache::instance($this->user);
		$cache->transaction();

		/* Get cached folders. */
		$foldersID = $cache->getFoldersID($this->accountID);

		/* Cache new folders. */
		@ksort($folders);

		if($folders) foreach ($folders as $folder) {

			if (isset($foldersID[$folder->name])) {
				$folderID = &$foldersID[$folder->name];
				if ($folder->rights != $folderID['rights']) {
					$cache->updateFolder($folderID['folder_id'],
										 array('rights' => $folder->rights));
				}

				$folderID = $folderID['folder_id'];
			} else {
				$parentFolderName = preg_replace('/\/[^\/]*$/', '',
												 $folder->name);

				if (isset($foldersID[$parentFolderName])
					&& !is_array($foldersID[$parentFolderName]))
				{
					$parentFolderID = $foldersID[$parentFolderName];
				} else
					$parentFolderID = null;
        
				$folderID = $cache->createFolder(array('parent_folder_id' => $parentFolderID,
														'account_id'		=> $this->accountID,
														'name'			 =>  $folder->name,
														'rights'			=> $folder->rights));
				$foldersID[$folder->name] = $folderID;
			}
		}

		/* Delete folders from the folder cache. */
		foreach ($foldersID as $folderID) {
			if (is_array($folderID))
				$cache->deleteFolder($this->accountID, $folderID['folder_id']);
		}

		$cache->commit();

		/* Update the internal list of folders. */
		$oAccount = $this->user->getAccount($this->accountID);

	  $this->loadFolders($this->folderClassName);
	}

  
  public function cleanUpCache(){
    $cache = Cache::instance($this->user);
    foreach($this->folders["main"] as $sFolderID => $oFolder)
      $cache->deleteFolder($this->accountID,$oFolder->folderID);
  }
}

require_once('inc/imap/account.php');

?>
